==> classpath-0.11.tar.gz: classpath-0.11/java/awt/font/TextMeasurer.java <==
/* TextMeasurer.java
   Copyright (C) 2003 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.awt.font;

import java.text.AttributedCharacterIterator;

/**
 * @author Michael Koch
 * @since 1.3
 */
public final class TextMeasurer implements Cloneable
{
  private AttributedCharacterIterator ci;
  private FontRenderContext frc;
  
  public TextMeasurer (AttributedCharacterIterator text, FontRenderContext frc)
  {
    this.ci = text;
    this.frc = frc;
  }

  protected Object clone ()
  {
    try
      {
        return super.clone ();
      }
    catch (CloneNotSupportedException e)
      {
        // This may never occur
        throw new InternalError ();
      }
  }

  public void deleteChar (AttributedCharacterIterator newParagraph,
                          int deletePos)
  {
    throw new Error ("not implemented");
  }

  public float getAdvanceBetween (int start, int limit)
  {
    throw new Error ("not implemented");
  }

  public TextLayout getLayout (int start, int limit)
  {
    throw new Error ("not implemented");
  }

  public int getLineBreakIndex (int start, float maxAdvance)
  {
    throw new Error ("not implemented");
  }

  public void insertChar (AttributedCharacterIterator newParagraph,
                          int insertPos)
  {
    throw new Error ("not implemented");
  }
}

==> classpath-0.91.tar.gz: classpath-0.91/java/awt/font/TextMeasurer.java <==
/* TextMeasurer.java
   Copyright (C) 2003 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.awt.font;

import gnu.classpath.NotImplementedException;

import java.text.AttributedCharacterIterator;

/**
 * @author Michael Koch
 * @since 1.3
 */
public final class TextMeasurer implements Cloneable
{
  private AttributedCharacterIterator ci;
  private FontRenderContext frc;
  
  public TextMeasurer (AttributedCharacterIterator text, FontRenderContext frc)
  {
    this.ci = text;
    this.frc = frc;
  }

  protected Object clone ()
  {
    try
      {
        return super.clone ();
      }
    catch (CloneNotSupportedException e)
      {
        // This may never occur
        throw new InternalError ();
      }
  }

  public void deleteChar (AttributedCharacterIterator newParagraph,
                          int deletePos)
    throws NotImplementedException
  {
    throw new Error ("not implemented");
  }

  public float getAdvanceBetween (int start, int limit)
    throws NotImplementedException
  {
    throw new Error ("not implemented");
  }

  public TextLayout getLayout (int start, int limit)
    throws NotImplementedException
  {
    throw new Error ("not implemented");
  }

  public int getLineBreakIndex (int start, float maxAdvance)
    throws NotImplementedException
  {
    throw new Error ("not implemented");
  }

  public void insertChar (AttributedCharacterIterator newParagraph,
                          int insertPos)
    throws NotImplementedException
  {
    throw new Error ("not implemented");
  }
}
